pub struct SmartConfigurationDocument {Show 18 fields
pub issuer: Option<String>,
pub jwks_uri: Option<String>,
pub authorization_endpoint: Option<String>,
pub grant_types_supported: Vec<String>,
pub token_endpoint: String,
pub token_endpoint_auth_methods_supported: Option<Vec<String>>,
pub registration_endpoint: Option<String>,
pub smart_app_state_endpoint: Option<String>,
pub associated_endpoints: Option<Vec<SmartConfigurationAssociatedEndpoint>>,
pub user_access_brand_bundle: Option<String>,
pub user_access_brand_identifier: Option<String>,
pub scopes_supported: Option<Vec<String>>,
pub response_types_supported: Option<Vec<String>>,
pub management_endpoint: Option<String>,
pub introspection_endpoint: Option<String>,
pub revocation_endpoint: Option<String>,
pub capabilities: Vec<String>,
pub code_challenge_methods_supported: Vec<String>,
}Fields
issuer: Option<String>CONDITIONAL. String conveying this system’s OpenID Connect Issuer URL. Required if the server’s capabilities include sso-openid-connect; otherwise, omitted.
jwks_uri: Option<String>CONDITIONAL. String conveying this system’s JSON Web Key Set URL. Required if the server’s capabilities include sso-openid-connect; otherwise, optional.
CONDITIONAL. URL to the OAuth2 authorization endpoint. Required if server supports the launch-ehr or launch-standalone capability; otherwise, optional.
grant_types_supported: Vec<String>REQUIRED. Array of grant types supported at the token endpoint. The options are “authorization_code” (when SMART App Launch is supported) and “client_credentials” (when SMART Backend Services is supported).
token_endpoint: StringREQUIRED. URL to the OAuth2 token endpoint.
token_endpoint_auth_methods_supported: Option<Vec<String>>OPTIONAL. Array of client authentication methods supported by the token endpoint. The options are “client_secret_post”, “client_secret_basic”, and “private_key_jwt”.
registration_endpoint: Option<String>OPTIONAL. If available, URL to the OAuth2 dynamic registration endpoint for this FHIR server.
smart_app_state_endpoint: Option<String>OPTIONAL, DEPRECATED. URL to the EHR’s app state endpoint. Deprecated; use associated_endpoints with the smart-app-state capability instead.
associated_endpoints: Option<Vec<SmartConfigurationAssociatedEndpoint>>OPTIONAL. Array of objects for endpoints that share the same authorization mechanism as this FHIR endpoint, each with a “url” and “capabilities” array. This property is deemed experimental.
user_access_brand_bundle: Option<String>RECOMMENDED. URL for a Brand Bundle. See User Access Brands.
user_access_brand_identifier: Option<String>RECOMMENDED. Identifier for the primary entry in a Brand Bundle. See User Access Brands.
scopes_supported: Option<Vec<String>>RECOMMENDED. Array of scopes a client may request. See scopes and launch context. The server SHALL support all scopes listed here; additional scopes MAY be supported (so clients should not consider this an exhaustive list).
response_types_supported: Option<Vec<String>>RECOMMENDED. Array of OAuth2 response_type values that are supported. Implementers can refer to response_types defined in OAuth 2.0 (RFC 6749) and in OIDC Core.
management_endpoint: Option<String>RECOMMENDED. URL where an end-user can view which applications currently have access to data and can make adjustments to these access rights.
introspection_endpoint: Option<String>RECOMMENDED. URL to a server’s introspection endpoint that can be used to validate a token.
revocation_endpoint: Option<String>RECOMMENDED. URL to a server’s revoke endpoint that can be used to revoke a token.
capabilities: Vec<String>REQUIRED. Array of strings representing SMART capabilities (e.g., sso-openid-connect or launch-standalone) that the server supports.
code_challenge_methods_supported: Vec<String>REQUIRED. Array of PKCE code challenge methods supported. The S256 method SHALL be included in this list, and the plain method SHALL NOT be included in this list.